==> tasks-v1.8.8.zip: tasks/messages/pt/base.php <==
<?php

return [
    '1 Day before' => '1 Dia antes',
    '1 Month before' => '1 Mês antes',
    '1 Week before' => '1 Semana antes',
    '2 Days before' => '2 Dias antes',
    '2 Weeks before' => '2 Semanas antes',
    '3 Weeks before' => '3 Semanas antes',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Membros designados</strong> têm permissão para processar esta tarefa.',
    '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> a eliminação da tarefa',
    '<strong>Create</strong> task list' => '<strong>Criar</strong> lista de tarefas',
    '<strong>Edit</strong> task' => '<strong>Editar</strong> tarefa',
    '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tarefas',
    '<strong>New</strong> Task' => '<strong>Nova</strong> Tarefa',
    '<strong>Task</strong> Overview' => '<strong>Panorama</strong> das tarefas',
    '<strong>Tasks</strong>' => '<strong>Tarefas</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configuração do módulo <strong>Tarefas</strong>',
    '<strong>Your</strong> tasks' => '<strong>As tuas</strong> tarefas',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Um widget é um elemento adicionado à barra lateral do mural. Neste caso, proporciona aos utilizadores uma perspetiva das suas tarefas.',
    'Accept Task' => 'Aceitar Tarefa',
    'Add Deadline to space calendar' => 'Adicionar Prazo ao calendário do espaço',
    'Add checkpoint...' => 'Adicionar ponto de controlo...',
    'Add entry to main navigation' => 'Adicionar entrada ao menu principal',
    'Add reminder' => 'Adicionar lembrete',
    'Add responsible users' => 'Adicionar responsáveis',
    'Add schedule to the space calendar' => 'Adicionar calendarização ao calendário do espaço',
    'Add task' => 'Adicionar tarefa',
    'Add to space calendar' => 'Adicionar ao espaço do calendário',
    'Additional options' => 'Opções adicionais',
    'All Day' => 'Todo o Dia',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permite que a pessoa crie novas tarefas, e só poderá editar e apagar as que lhe pertencem',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite criar, apagar e editar tarefas e listas e também ordenar tarefas e listas',
    'Allows the user to process unassigned tasks' => 'Permite processar tarefas sem atribuição',
    'Already requested' => 'Já pedido',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Qualquer pessoa com a permissão "Processar tarefas não atribuídas" pode trabalhar nesta tarefa',
    'Anyone can work on this task!' => 'Qualquer pessoa pode trabalhar nesta tarefa!',
    'Assign myself' => 'Atribuir a mim',
    'Assign users' => 'Designar utilizadores',
    'Assigned' => 'Designado',
    'Assigned users' => 'Utilizadores designados',
    'Assignment' => 'Designação',
    'Assignments:' => 'Designações:',
    'At least 1 Hour before' => 'Pelo menos 1 Hora antes',
    'At least 2 Hours before' => 'Pelo menos 2 Hora antes',
    'Attachments' => 'Anexos',
    'Begin Task' => 'Começar Tarefa',
    'Checklist Items' => 'Itens da lista de controlo',
    'Checklist:' => 'Lista:',
    'Checkpoints' => 'Checkpoints',
    'Choose if you want the module to appear in the main navigation.' => 'Defina se pretende que este módulo seja exibido na navegação principal.',
    'Close' => 'Fechar',
    'Color' => 'Cor',
    'Completed' => 'Completa',
    'Completed lists' => 'Listas completadas',
    'Continue Review' => 'Continuar Revisão',
    'Create tasks' => 'Criar tarefas',
    'Created by me' => 'Criado por mim',
    'Date' => 'Data',
    'Deadline at' => 'Prazo em',
    'Deadline: ' => 'Prazo:',
    'Delete' => 'eliminar',
    'Delete list' => 'eliminar lista',
    'Description' => 'Descrição',
    'Do not remind' => 'Não lembrar',
    'Do you really want to delete this task?' => 'Queres mesmo eliminar esta tarefa?',
    'Don\'t add to calendar' => 'Não adicionar ao calendário',
    'Drag entry' => 'Arrastar entrada',
    'Edit' => 'Editar',
    'Edit item (empty field will be removed)...' => 'Editar item (um campo vazio será removido)...',
    'Edit list' => 'Editar lista',
    'End' => 'Fim',
    'End Date' => 'Data Final',
    'End Time' => 'Hora de Fim',
    'End date' => 'Data de Fim',
    'End time must be after start time!' => 'A hora de fim tem de ser depois da hora de início.',
    'Extend deadline request' => 'Pedir prolongamento do prazo',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtrar por estado',
    'Filter by title' => 'Filtrar por título',
    'Filter tasks' => 'Filtrar tarefas',
    'Finish Task' => 'Terminar Tarefa',
    'General' => 'Geral',
    'General Settings' => 'Definições gerais',
    'Hide this list once all tasks are completed' => 'Esconder esta lista assim que todas as tarefas estejam terminadas',
    'I\'m assigned' => 'Estou designado',
    'I\'m responsible' => 'Sou responsável',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se não houver membro designado, cada participante do espaço com permissão para trabalhar em tarefas não atribuídas pode trabalhar na tarefa.',
    'In Progress' => 'Em Progresso',
    'In Review' => 'Em Revisão',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Caso a opção de revisão esteja activa, uma <strong>pessoa responsável</strong> terá que rever e rejeitar ou confirmar esta tarefa antes da sua conclusão.',
    'Invalid task list selection.' => 'Selecção de lista de tarefas inválida.',
    'Let Task Review' => 'Revisão da Tarefa',
    'Manage tasks' => 'Gerir tarefas',
    'No Scheduling set for this Task' => 'Calendarização não definida para esta Tarefa',
    'No pending tasks found' => 'Não foram encontradas tarefas suspensas',
    'No results found for the given filter.' => 'Não foram encontrados resultados para o filtro utilizado.',
    'Open Task' => 'Abrir Tarefa',
    'Other Tasks' => 'Outras Tarefas',
    'Overdue' => 'Fora de Prazo',
    'Overview' => 'Visão Geral',
    'Parent Task' => 'Tarefa Mãe',
    'Pending' => 'Pendente',
    'Pending Review' => 'Pendente de Revisão',
    'Process unassigned tasks' => 'Processar tarefas sem atribuição',
    'Ready For Review' => 'Pronto para Revisão',
    'Receive Notifications for Task Reminder.' => 'Receber Notificações para Avisos de Tarefas',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Receber Notificações para Tarefas (Atualizações, mudanças de estado...).',
    'Reject Task' => 'Rejeitar Tarefa',
    'Remind Mode' => 'Modo de Lembrete',
    'Reminder' => 'Lembrete',
    'Reminder sent' => 'Lembrete enviado',
    'Reminders' => 'Lembretes',
    'Request extension' => 'Pedir extensão',
    'Request sent' => 'Pedido enviado',
    'Reset Task' => 'Redefinir Tarefa',
    'Responsible' => 'Responsável',
    'Review by responsible user required' => 'Revisão por responsável necessária',
    'Scheduling' => 'Calendarização',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar mais {countTasks,plural,=1{# tarefa terminada} other{# tarefas terminadas}}',
    'Sort Order' => 'Ordenação',
    'Sort order' => 'Ordenação',
    'Spaces' => 'Espaços',
    'Start' => 'Início',
    'Start Date' => 'Data Inicial',
    'Start Time' => 'Hora de Início',
    'Start date' => 'Data inicial',
    'Starting at' => 'Iniciando em',
    'Status' => 'Estado',
    'Task' => 'Tarefa',
    'Task List' => 'Lista de Tarefas',
    'Task Users have been notified' => 'As pessoas desta tarefa foram notificadas',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} termina em {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} começa em {dateTime}.',
    'Tasks' => 'Tarefas',
    'Tasks: Reminder' => 'Tarefas: Lembrete',
    'This task can only be processed by assigned and responsible users.' => 'Esta tarefa só pode ser processada por quem recebeu atribuição ou é responsável por ela.',
    'This task requires to be reviewed by a responsible' => 'Esta tarefa requere que seja revista por um responsável',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Title and Color' => 'Título e Cor',
    'Title of your task list' => 'Título da sua lista de tarefas',
    'Today' => 'Hoje',
    'Unsorted' => 'Desordenada',
    'View Online' => 'Ver Online',
    'You are assigned!' => 'Estás designado!',
    'You are responsible!' => 'És responsável!',
    'You have insufficient permissions to perform that operation!' => 'Não tens permissões suficientes para executar essa operação!',
    'Your Reminder for task {task}' => 'Teu Lembrete para a tarefa {task}',
    'ending Review' => 'Revisão final',
    'view all' => 'ver tudo',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{Falta # dia} other{Faltam # dias}}',
    '{displayName} is assigned to this task' => '{displayName} está designado para esta tarefa',
    '{displayName} is responsible for this task' => '{displayName} é responsável por esta tarefa',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} designou-te para a tarefa {task} do espaço {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} designou-te a tarefa {task} no espaço {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} completou a tarefa {task} no espaço {spaceName}.',
    '{userName} completed task {task}.' => '{userName} completou a tarefa {task}.',
    '{userName} finished task {task}.' => '{userName} finalizou a tarefa {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} alterou o prazo da tarefa {task} no espaço {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} reabriu a tarefa {task} no espaço {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} rejeitou a tarefa {task} no espaço {spaceName} como incompleta.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcou a tarefa {task} no espaço {spaceName} como completa.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} pede um aumento do prazo da tarefa {task} no espaço {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} pede que revejas a tarefa {task} no espaço {spaceName}.',
    '{userName} reset task {task}.' => '{userName} redefiniu a tarefa {task}.',
    '{userName} reviewed task {task}.' => '{userName} reviu a tarefa {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} começou a trabalhar na tarefa {task} no espaço {spaceName}.',
    '{userName} works on task {task}.' => '{userName} está a trabalhar na tarefa {task}.',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task content ID' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/pt/base.php <==
<?php

return [
    '1 Day before' => '1 Dia antes',
    '1 Month before' => '1 Mês antes',
    '1 Week before' => '1 Semana antes',
    '2 Days before' => '2 Dias antes',
    '2 Weeks before' => '2 Semanas antes',
    '3 Weeks before' => '3 Semanas antes',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Membros designados</strong> têm permissão para processar esta tarefa.',
    '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> a eliminação da tarefa',
    '<strong>Create</strong> task list' => '<strong>Criar</strong> lista de tarefas',
    '<strong>Edit</strong> task' => '<strong>Editar</strong> tarefa',
    '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tarefas',
    '<strong>New</strong> Task' => '<strong>Nova</strong> Tarefa',
    '<strong>Task</strong> Overview' => '<strong>Panorama</strong> das tarefas',
    '<strong>Tasks</strong>' => '<strong>Tarefas</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configuração do módulo <strong>Tarefas</strong>',
    '<strong>Your</strong> tasks' => '<strong>As tuas</strong> tarefas',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Um widget é um elemento adicionado à barra lateral do mural. Neste caso, proporciona aos utilizadores uma perspetiva das suas tarefas.',
    'Accept Task' => 'Aceitar Tarefa',
    'Add Deadline to space calendar' => 'Adicionar Prazo ao calendário do espaço',
    'Add checkpoint...' => 'Adicionar ponto de controlo...',
    'Add entry to main navigation' => 'Adicionar entrada ao menu principal',
    'Add reminder' => 'Adicionar lembrete',
    'Add responsible users' => 'Adicionar responsáveis',
    'Add schedule to the space calendar' => 'Adicionar calendarização ao calendário do espaço',
    'Add task' => 'Adicionar tarefa',
    'Add to space calendar' => 'Adicionar ao espaço do calendário',
    'Additional options' => 'Opções adicionais',
    'All Day' => 'Todo o Dia',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permite que a pessoa crie novas tarefas, e só poderá editar e apagar as que lhe pertencem',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite criar, apagar e editar tarefas e listas e também ordenar tarefas e listas',
    'Allows the user to process unassigned tasks' => 'Permite processar tarefas sem atribuição',
    'Already requested' => 'Já pedido',
    'Assign myself' => 'Atribuir a mim',
    'Assign users' => 'Designar utilizadores',
    'Assigned users' => 'Utilizadores designados',
    'Assignment' => 'Designação',
    'At least 1 Hour before' => 'Pelo menos 1 Hora antes',
    'At least 2 Hours before' => 'Pelo menos 2 Hora antes',
    'Attachments' => 'Anexos',
    'Begin Task' => 'Começar Tarefa',
    'Checklist Items' => 'Itens da lista de controlo',
    'Checklist:' => 'Lista:',
    'Checkpoints' => 'Checkpoints',
    'Choose if you want the module to appear in the main navigation.' => 'Defina se pretende que este módulo seja exibido na navegação principal.',
    'Close' => 'Fechar',
    'Color' => 'Cor',
    'Completed' => 'Completa',
    'Completed lists' => 'Listas completadas',
    'Continue Review' => 'Continuar Revisão',
    'Create tasks' => 'Criar tarefas',
    'Created by me' => 'Criado por mim',
    'Date' => 'Data',
    'Deadline: ' => 'Prazo:',
    'Delete' => 'eliminar',
    'Delete list' => 'eliminar lista',
    'Description' => 'Descrição',
    'Do not remind' => 'Não lembrar',
    'Do you really want to delete this task?' => 'Queres mesmo eliminar esta tarefa?',
    'Don\'t add to calendar' => 'Não adicionar ao calendário',
    'Edit' => 'Editar',
    'Edit item (empty field will be removed)...' => 'Editar item (um campo vazio será removido)...',
    'Edit list' => 'Editar lista',
    'End' => 'Fim',
    'End Date' => 'Data Final',
    'End Time' => 'Hora de Fim',
    'End date' => 'Data de Fim',
    'End time must be after start time!' => 'A hora de fim tem de ser depois da hora de início.',
    'Extend deadline request' => 'Pedir prolongamento do prazo',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtrar por estado',
    'Filter by title' => 'Filtrar por título',
    'Filter tasks' => 'Filtrar tarefas',
    'Finish Task' => 'Terminar Tarefa',
    'General' => 'Geral',
    'General Settings' => 'Definições gerais',
    'Hide this list once all tasks are completed' => 'Esconder esta lista assim que todas as tarefas estejam terminadas',
    'I\'m assigned' => 'Estou designado',
    'I\'m responsible' => 'Sou responsável',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se não houver membro designado, cada participante do espaço com permissão para trabalhar em tarefas não atribuídas pode trabalhar na tarefa.',
    'In Progress' => 'Em Progresso',
    'In Review' => 'Em Revisão',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Caso a opção de revisão esteja activa, uma <strong>pessoa responsável</strong> terá que rever e rejeitar ou confirmar esta tarefa antes da sua conclusão.',
    'Invalid task list selection.' => 'Selecção de lista de tarefas inválida.',
    'Let Task Review' => 'Revisão da Tarefa',
    'Manage tasks' => 'Gerir tarefas',
    'No Scheduling set for this Task' => 'Calendarização não definida para esta Tarefa',
    'No pending tasks found' => 'Não foram encontradas tarefas suspensas',
    'No results found for the given filter.' => 'Não foram encontrados resultados para o filtro utilizado.',
    'Open Task' => 'Abrir Tarefa',
    'Other Tasks' => 'Outras Tarefas',
    'Overdue' => 'Fora de Prazo',
    'Overview' => 'Visão Geral',
    'Parent Task' => 'Tarefa Mãe',
    'Pending' => 'Pendente',
    'Pending Review' => 'Pendente de Revisão',
    'Process unassigned tasks' => 'Processar tarefas sem atribuição',
    'Ready For Review' => 'Pronto para Revisão',
    'Receive Notifications for Task Reminder.' => 'Receber Notificações para Avisos de Tarefas',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Receber Notificações para Tarefas (Atualizações, mudanças de estado...).',
    'Reject Task' => 'Rejeitar Tarefa',
    'Remind Mode' => 'Modo de Lembrete',
    'Reminder' => 'Lembrete',
    'Reminder sent' => 'Lembrete enviado',
    'Reminders' => 'Lembretes',
    'Request extension' => 'Pedir extensão',
    'Request sent' => 'Pedido enviado',
    'Reset Task' => 'Redefinir Tarefa',
    'Responsible' => 'Responsável',
    'Review by responsible user required' => 'Revisão por responsável necessária',
    'Scheduling' => 'Calendarização',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar mais {countTasks,plural,=1{# tarefa terminada} other{# tarefas terminadas}}',
    'Sort Order' => 'Ordenação',
    'Sort order' => 'Ordenação',
    'Spaces' => 'Espaços',
    'Start' => 'Início',
    'Start Date' => 'Data Inicial',
    'Start Time' => 'Hora de Início',
    'Start date' => 'Data inicial',
    'Starting at' => 'Iniciando em',
    'Status' => 'Estado',
    'Task' => 'Tarefa',
    'Task List' => 'Lista de Tarefas',
    'Task Users have been notified' => 'As pessoas desta tarefa foram notificadas',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} termina em {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} começa em {dateTime}.',
    'Tasks' => 'Tarefas',
    'Tasks: Reminder' => 'Tarefas: Lembrete',
    'This task requires to be reviewed by a responsible' => 'Esta tarefa requere que seja revista por um responsável',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Title and Color' => 'Título e Cor',
    'Title of your task list' => 'Título da sua lista de tarefas',
    'Today' => 'Hoje',
    'Unsorted' => 'Desordenada',
    'View Online' => 'Ver Online',
    'You have insufficient permissions to perform that operation!' => 'Não tens permissões suficientes para executar essa operação!',
    'Your Reminder for task {task}' => 'Teu Lembrete para a tarefa {task}',
    'view all' => 'ver tudo',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{Falta # dia} other{Faltam # dias}}',
    '{displayName} is assigned to this task' => '{displayName} está designado para esta tarefa',
    '{displayName} is responsible for this task' => '{displayName} é responsável por esta tarefa',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} designou-te para a tarefa {task} do espaço {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} designou-te a tarefa {task} no espaço {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} completou a tarefa {task} no espaço {spaceName}.',
    '{userName} completed task {task}.' => '{userName} completou a tarefa {task}.',
    '{userName} finished task {task}.' => '{userName} finalizou a tarefa {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} alterou o prazo da tarefa {task} no espaço {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} reabriu a tarefa {task} no espaço {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} rejeitou a tarefa {task} no espaço {spaceName} como incompleta.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcou a tarefa {task} no espaço {spaceName} como completa.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} pede um aumento do prazo da tarefa {task} no espaço {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} pede que revejas a tarefa {task} no espaço {spaceName}.',
    '{userName} reset task {task}.' => '{userName} redefiniu a tarefa {task}.',
    '{userName} reviewed task {task}.' => '{userName} reviu a tarefa {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} começou a trabalhar na tarefa {task} no espaço {spaceName}.',
    '{userName} works on task {task}.' => '{userName} está a trabalhar na tarefa {task}.',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Assignments' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Request Review' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
